tui

package
v0.0.0-...-64dd23c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Select

func Select(entries []Entry) (string, error)

Select displays an interactive fuzzy selector and returns the selected worktree path. Returns empty string if the user cancels.

func SelectBranch

func SelectBranch(entries []BranchEntry, header string) (string, error)

SelectBranch displays an interactive fuzzy selector for branches. Returns the selected branch name, or empty string if cancelled.

Types

type BranchEntry

type BranchEntry struct {
	Name        string
	Source      string // "local" or "remote"
	HasWorktree bool
}

BranchEntry represents a branch in the branch selector.

type Entry

type Entry struct {
	Branch string
	Path   string
	Rel    string
}

Entry represents a worktree entry in the selector.

Jump to