Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Select ¶
Select displays an interactive fuzzy selector and returns the selected worktree path. Returns empty string if the user cancels.
func SelectBranch ¶
func SelectBranch(entries []BranchEntry, header string) (string, error)
SelectBranch displays an interactive fuzzy selector for branches. Returns the selected branch name, or empty string if cancelled.
Types ¶
type BranchEntry ¶
BranchEntry represents a branch in the branch selector.
Click to show internal directories.
Click to hide internal directories.